Re-exports
pub use types::Input;pub use proc_macro2;pub use quote;pub use syn;pub use diagnostic::*;pub use extract::*;pub use meta::*;
Modules
Macros
- camel
- Converts a string or ident to camelCase.
- format_
ident - Formatting macro for constructing
Idents. - kebab
- Converts a string or ident to kebab-case.
- parse
- parse_
input - pascal
- Converts a string or ident to PascalCase.
- screaming
- Converts a string or ident to SCREAMING_SNAKE_CASE.
- snake
- Converts a string or ident to snake_case.
Structs
- Span
- A region of source code, along with macro expansion information.
- Token
Stream - An abstract stream of tokens, or more concretely a sequence of token trees.